import type { CookieSerializeOptions } from 'cookie';
export declare type OnVerifyHookReturn = string | undefined | null;
export declare type SatpamSession = {
    status: boolean;
    token: string;
};
export declare type SatpamOptions = {
    /** cookie name, default: satpam */
    name?: string;
    /** insert url query or hash parameter name to include url check */
    urlCheck?: string;
    /** if true, set cookie automaticly on verify function when token found. default: true */
    autoSetCookie?: boolean;
};
export declare class Satpam {
    /** Request Headers */
    private request;
    /** Response Headers */
    private response;
    /** found token */
    private token;
    /** cookie session */
    private session;
    /** cookie name */
    private name;
    /** url param/hash to check */
    private urlCheck;
    /** hook on verify done */
    private hook;
    /** auto set cookie flag */
    private autoSetCookie;
    constructor(req: {
        headers: object | Headers;
        url: string | URL;
    }, res: {
        headers: object | Headers;
    }, opt?: SatpamOptions);
    /**
     * url parameter check utility
     *
     * @private
     * @param {string} params
     * @return {SatpamVerifyReturn} status, token
     * @memberof Satpam
     */
    private _urlParamCheck;
    private _processToken;
    /**
     * Verify jwt token exist
     *
     * @param {OnVerifyHook} Hook on token found
     * @return {SatpamVerifyReturn} status, token
     * @memberof Satpam
     */
    verify(cb?: (token: string) => OnVerifyHookReturn): Promise<SatpamSession>;
    /**
     * set session by adding token to response cookie header
     *
     * @param {string} [token=""]
     * @param {CookieSerializeOptions} [opt={}]
     * @return {string} string formated cookie
     * @memberof Satpam
     */
    setSession(token?: string, opt?: CookieSerializeOptions): string;
    /**
     * return current session
     *
     * @return {SatpamSession} session
     * @memberof Satpam
     */
    getSession(): SatpamSession;
}
